/*
HDD Explorer AppList Editor 
Copyright (c) 2006 Bruno Freitas
bootsector@ig.com.br
 
Permission is hereby granted, free of charge, to any person obtaining a copy of
this software and associated documentation files (the "Software"), to deal in
the Software without restriction, including without limitation the rights to
use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
of the Software, and to permit persons to whom the Software is furnished to do
so, subject to the following conditions:
 
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
 
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
*/

import java.io.*;
import javax.swing.*;

public class AppList {
    public static void GeraAppList(DefaultListModel lista, String diretorio) {
        try {
            RandomAccessFile arquivo = new RandomAccessFile(diretorio + "/APPLIST.DAT", "rw");
            byte assinatura[] = {'D', 'M', 'S', '3'};
            int versao = 0x10;
            int checksum = 0;
            int n_aplicacoes;
            
            n_aplicacoes = lista.size();
            
            arquivo.setLength(0);
            
            arquivo.write(assinatura);
            arquivo.writeInt(toLittleEndian(checksum));
            arquivo.writeInt(toLittleEndian(versao));
            arquivo.writeInt(toLittleEndian(n_aplicacoes));
            
            for (int i = 0; i < lista.size(); i++) {
                Aplicacao app = (Aplicacao) lista.get(i);
                
                arquivo.write(app.getTitulo().getBytes());
                for (int j = 1; j <= (128-app.getTitulo().length()); j++) {
                    arquivo.write(0);
                    checksum++;
                }
                
                arquivo.write(app.getAutor().getBytes());
                for (int j = 1; j <= (32-app.getAutor().length()); j++) {
                    arquivo.write(0);
                    checksum++;
                }
                
                arquivo.write(app.getDescricao().getBytes());
                for (int j = 1; j <= (1024-app.getDescricao().length()); j++) {
                    arquivo.write(0);
                    checksum++;
                }
                
                arquivo.write(app.getExecutavel().getBytes());
                for (int j = 1; j <= (128-app.getExecutavel().length()); j++) {
                    arquivo.write(0);
                    checksum++;
                }
            }
            
            arquivo.seek(4);
            arquivo.writeInt(toLittleEndian(checksum));
            
            arquivo.close();
        } catch (Exception ex) {}
    }
    
    public static void AbreAppList(DefaultListModel lista, String nome_arquivo, JFrame janela) {
        try {
            RandomAccessFile arquivo = new RandomAccessFile(nome_arquivo, "r");
            byte assinatura[] = new byte[4];
            
            byte titulo[] = new byte[128];
            byte autor[] = new byte[32];
            byte descricao[] = new byte[1024];
            byte executavel[] = new byte[128];
            
            int total_aplicacoes, cont;
            
            arquivo.read(assinatura);
            
            if ((new String(assinatura)).compareTo("DMS3") != 0) {
                JOptionPane.showMessageDialog(janela, "O arquivo selecionado no  um arquivo APPLIST.DAT vlido!", "Ateno", JOptionPane.INFORMATION_MESSAGE);
                arquivo.close();
                return;
            }
            
            arquivo.seek(12);
            total_aplicacoes = toLittleEndian(arquivo.readInt());
            
            arquivo.seek(16);
            lista.removeAllElements();
            
            cont = 1;
            while ((arquivo.read(titulo) != -1) && (cont <= total_aplicacoes)) {
                arquivo.read(autor);
                arquivo.read(descricao);
                arquivo.read(executavel);
                
                String s_titulo = new String(titulo);
                String s_autor = new String(autor);
                String s_descricao = new String(descricao);
                String s_executavel = new String(executavel);
                
                s_titulo = s_titulo.substring(0, s_titulo.indexOf(0));
                s_autor = s_autor.substring(0, s_autor.indexOf(0));
                s_descricao = s_descricao.substring(0, s_descricao.indexOf(0));
                s_executavel = s_executavel.substring(0, s_executavel.indexOf(0));
                
                Aplicacao aplicacao = new Aplicacao();
                
                aplicacao.setTitulo(s_titulo);
                aplicacao.setAutor(s_autor);
                aplicacao.setDescricao(s_descricao);
                aplicacao.setExecutavel(s_executavel);
                
                lista.addElement(aplicacao);
                cont++;
            }
            
            arquivo.close();
        } catch (Exception ex){}
    }
    
    private static int toLittleEndian(int v) {
        return (v >>> 24) | (v << 24) | ((v << 8) & 0x00FF0000) | ((v >> 8) & 0x0000FF00);
    }
    
}
